==> ZendFramework-1.6.2.tar.gz: ZendFramework-1.6.2/externals/dojo/dojo/nls/pt-pt/colors.js <==
({
// local representation of all CSS3 named colors, companion to dojo.colors.  To be used where descriptive information
// is required for each color, such as a palette widget, and not for specifying color programatically.

//Note: due to the SVG 1.0 spec additions, some of these are alternate spellings for the same color e.g. gray vs. gray. 
//TODO: should we be using unique rgb values as keys instead and avoid these duplicates, or rely on the caller to do the reverse mapping?
aliceblue: "azul alice",
antiquewhite: "branco antigo",
aqua: "verde-água",
aquamarine: "verde-azulado",
azure: "azul-celeste",
beige: "bege",
bisque: "rosa-velho",
black: "preto",
blanchedalmond: "amêndoa claro",
blue: "azul",
blueviolet: "azul violeta",
brown: "castanho",
burlywood: "castanho pinho",
cadetblue: "azul cadete",
chartreuse: "amarelo esverdeado",
chocolate: "chocolate",
coral: "coral",
cornflowerblue: "azul-violáceo",
cornsilk: "branco seda",
crimson: "carmesim",
cyan: "ciano",
darkblue: "azul escuro",
darkcyan: "ciano escuro",
darkgoldenrod: "ouro velho escuro",
darkgray: "cinzento escuro",
darkgreen: "verde escuro",
darkgrey: "cinzento escuro", // same as darkgray
darkkhaki: "caqui escuro",
darkmagenta: "magenta escuro",
darkolivegreen: "verde-azeitona escuro",
darkorange: "laranja escuro",
darkorchid: "orquídea escuro",
darkred: "vermelho escuro",
darksalmon: "salmão escuro",
darkseagreen: "verde marinho escuro",
darkslateblue: "azul ardósia escuro",
darkslategray: "cinzento ardósia escuro",
darkslategrey: "cinzento ardósia escuro",// same as darkslategray
darkturquoise: "turquesa escuro",
darkviolet: "violeta escuro",
deeppink: "rosa profundo",
deepskyblue: "azul céu profundo",
dimgray: "cinzento escuro",
dimgrey: "cinzento escuro", // same as dimgray
dodgerblue: "azul furtivo",
firebrick: "tijolo fogo",
floralwhite: "branco floral",
forestgreen: "verde floresta",
fuchsia: "fúcsia",
gainsboro: "cinzento azulado claro",
ghostwhite: "branco sombreado",
gold: "dourado",
goldenrod: "ouro velho",
gray: "cinzento",
green: "verde",
greenyellow: "amarelo esverdeado",
grey: "cinzento", // same as gray
honeydew: "mel",
hotpink: "rosa forte",
indianred: "almagre",
indigo: "índigo",
ivory: "marfim",
khaki: "caqui",
lavender: "alfazema",
lavenderblush: "alfazema rosado",
lawngreen: "verde relva",
lemonchiffon: "limão chiffon",
lightblue: "azul claro",
lightcoral: "coral claro",
lightcyan: "ciano claro",
lightgoldenrodyellow: "ouro velho amarelado claro",
lightgray: "cinzento claro",
lightgreen: "verde claro",
lightgrey: "cinzento claro", // same as lightgray
lightpink: "rosa claro",
lightsalmon: "salmão claro",
lightseagreen: "verde marinho claro",
lightskyblue: "azul céu claro",
lightslategray: "cinzento ardósia claro",
lightslategrey: "cinzento ardósia claro", // same as lightslategray
lightsteelblue: "azul-aço claro",
lightyellow: "amarelo claro",
lime: "lima",
limegreen: "verde-lima",
linen: "linho",
magenta: "magenta",
maroon: "bordeaux",
mediumaquamarine: "verde-azulado médio",
mediumblue: "azul médio",
mediumorchid: "orquídea médio",
mediumpurple: "roxo médio",
mediumseagreen: "verde marinho médio",
mediumslateblue: "azul ardósia médio",
mediumspringgreen: "verde primavera médio",
mediumturquoise: "turquesa médio",
mediumvioletred: "violeta avermelhado médio",
midnightblue: "azul meia-noite",
mintcream: "creme de menta",
mistyrose: "rosa pálido",
moccasin: "mocassim",
navajowhite: "branco navajo",
navy: "azul marinho",
oldlace: "renda antiga",
olive: "azeitona",
olivedrab: "azeitona claro",
orange: "laranja",
orangered: "vermelho alaranjado",
orchid: "orquídea",
palegoldenrod: "ouro velho pálido",
palegreen: "verde pálido",
paleturquoise: "turquesa pálido",
palevioletred: "violeta avermelhado pálido",
papayawhip: "creme de papaia",
peachpuff: "pêssego",
peru: "peru",
pink: "rosa",
plum: "cor-de-ameixa",
powderblue: "azul de esmalte",
purple: "roxo",
red: "vermelho",
rosybrown: "castanho rosado",
royalblue: "azul real",
saddlebrown: "castanho sela",
salmon: "salmão",
sandybrown: "castanho areia",
seagreen: "verde marinho",
seashell: "concha",
sienna: "castanho-avermelhado",
silver: "prateado",
skyblue: "azul céu",
slateblue: "azul ardósia",
slategray: "cinzento ardósia",
slategrey: "cinzento ardósia", // same as slategray
snow: "branco-neve",
springgreen: "verde primavera",
steelblue: "azul-aço",
tan: "castanho claro",
teal: "verde-azulado",
thistle: "cardo",
tomato: "vermelho tomate",
turquoise: "turquesa",
violet: "violeta",
wheat: "trigo",
white: "branco",
whitesmoke: "fumo branco",
yellow: "amarelo",
yellowgreen: "verde amarelado"
})

==> ZendFramework-1.12.7.tar.gz: ZendFramework-1.12.7/externals/dojo/dojo/nls/pt-pt/colors.js <==
({
// local representation of all CSS3 named colors, companion to dojo.colors.  To be used where descriptive information
// is required for each color, such as a palette widget, and not for specifying color programatically.

//Note: due to the SVG 1.0 spec additions, some of these are alternate spellings for the same color e.g. gray vs. gray. 
//TODO: should we be using unique rgb values as keys instead and avoid these duplicates, or rely on the caller to do the reverse mapping?
aliceblue: "azul alice",
antiquewhite: "branco antigo",
aqua: "verde-água",
aquamarine: "verde-azulado",
azure: "azul-celeste",
beige: "bege",
bisque: "rosa-velho",
black: "preto",
blanchedalmond: "amêndoa claro",
blue: "azul",
blueviolet: "azul violeta",
brown: "castanho",
burlywood: "castanho pinho",
cadetblue: "azul cadete",
chartreuse: "amarelo esverdeado",
chocolate: "chocolate",
coral: "coral",
cornflowerblue: "azul-violáceo",
cornsilk: "branco seda",
crimson: "carmesim",
cyan: "ciano",
darkblue: "azul escuro",
darkcyan: "ciano escuro",
darkgoldenrod: "ouro velho escuro",
darkgray: "cinzento escuro",
darkgreen: "verde escuro",
darkgrey: "cinzento escuro", // same as darkgray
darkkhaki: "caqui escuro",
darkmagenta: "magenta escuro",
darkolivegreen: "verde-azeitona escuro",
darkorange: "laranja escuro",
darkorchid: "orquídea escuro",
darkred: "vermelho escuro",
darksalmon: "salmão escuro",
darkseagreen: "verde marinho escuro",
darkslateblue: "azul ardósia escuro",
darkslategray: "cinzento ardósia escuro",
darkslategrey: "cinzento ardósia escuro", // same as darkslategray
darkturquoise: "turquesa escuro",
darkviolet: "violeta escuro",
deeppink: "rosa profundo",
deepskyblue: "azul céu profundo",
dimgray: "cinzento esbatido",
dimgrey: "cinzento esbatido", // same as dimgray
dodgerblue: "azul furtivo",
firebrick: "tijolo fogo",
floralwhite: "branco floral",
forestgreen: "verde floresta",
fuchsia: "fúcsia",
gainsboro: "cinzento azulado claro",
ghostwhite: "branco sombreado",
gold: "dourado",
goldenrod: "ouro velho",
gray: "cinzento",
green: "verde",
greenyellow: "amarelo esverdeado",
grey: "cinzento", // same as gray
honeydew: "mel",
hotpink: "rosa forte",
indianred: "almagre",
indigo: "índigo",
ivory: "marfim",
khaki: "caqui",
lavender: "alfazema",
lavenderblush: "alfazema rosado",
lawngreen: "verde relva",
lemonchiffon: "limão chiffon",
lightblue: "azul claro",
lightcoral: "coral claro",
lightcyan: "ciano claro",
lightgoldenrodyellow: "ouro velho amarelado claro",
lightgray: "cinzento claro",
lightgreen: "verde claro",
lightgrey: "cinzento claro", // same as lightgray
lightpink: "rosa claro",
lightsalmon: "salmão claro",
lightseagreen: "verde marinho claro",
lightskyblue: "azul céu claro",
lightslategray: "cinzento ardósia claro",
lightslategrey: "cinzento ardósia claro", // same as lightslategray
lightsteelblue: "azul-aço claro",
lightyellow: "amarelo claro",
lime: "lima",
limegreen: "verde-lima",
linen: "linho",
magenta: "magenta",
maroon: "bordeaux",
mediumaquamarine: "verde-azulado médio",
mediumblue: "azul médio",
mediumorchid: "orquídea médio",
mediumpurple: "roxo médio",
mediumseagreen: "verde marinho médio",
mediumslateblue: "azul ardósia médio",
mediumspringgreen: "verde primavera médio",
mediumturquoise: "turquesa médio",
mediumvioletred: "violeta avermelhado médio",
midnightblue: "azul meia-noite",
mintcream: "creme de menta",
mistyrose: "rosa pálido",
moccasin: "mocassim",
navajowhite: "branco navajo",
navy: "azul marinho",
oldlace: "renda antiga",
olive: "azeitona",
olivedrab: "azeitona claro",
orange: "laranja",
orangered: "vermelho alaranjado",
orchid: "orquídea",
palegoldenrod: "ouro velho pálido",
palegreen: "verde pálido",
paleturquoise: "turquesa pálido",
palevioletred: "violeta avermelhado pálido",
papayawhip: "creme de papaia",
peachpuff: "pêssego",
peru: "peru",
pink: "rosa",
plum: "cor-de-ameixa",
powderblue: "azul de esmalte",
purple: "roxo",
red: "vermelho",
rosybrown: "castanho rosado",
royalblue: "azul real",
saddlebrown: "castanho sela",
salmon: "salmão",
sandybrown: "castanho areia",
seagreen: "verde marinho",
seashell: "concha",
sienna: "castanho-avermelhado",
silver: "prateado",
skyblue: "azul céu",
slateblue: "azul ardósia",
slategray: "cinzento ardósia",
slategrey: "cinzento ardósia", // same as slategray
snow: "branco-neve",
springgreen: "verde primavera",
steelblue: "azul-aço",
tan: "castanho claro",
teal: "verde-azulado",
thistle: "cardo",
tomato: "vermelho tomate",
turquoise: "turquesa",
violet: "violeta",
wheat: "trigo",
white: "branco",
whitesmoke: "fumo branco",
yellow: "amarelo",
yellowgreen: "verde amarelado"
})
